// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/* jshint node: true, browser: false */
/* eslint-env node */

/**
 * @copyright  2014 Andrew Nicols
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/**
 * Grunt configuration
 */

module.exports = function (grunt) {
    let path = require('path'),
        cwd = process.env.PWD || process.cwd(),
        inAMD = path.basename(cwd) === 'amd';

    const sass = require('node-sass');

    // Globbing pattern for matching all AMD JS source files.
    let amdSrc = [inAMD ? cwd + '/src/*.js' : '**/amd/src/*.js'];

    /**
     * Function to generate the destination for the uglify task
     * (e.g. build/file.min.js). This function will be passed to
     * the rename property of files array when building dynamically:
     * http://gruntjs.com/configuring-tasks#building-the-files-object-dynamically
     *
     * @param {String} destPath the current destination
     * @param {String} srcPath the  matched src path
     * @return {String} The rewritten destination path.
     */
    let uglifyRename = function (destPath, srcPath) {
        destPath = srcPath.replace('src', 'build');
        destPath = destPath.replace('.js', '.min.js');
        destPath = path.resolve(cwd, destPath);
        return destPath;
    };

    // Project configuration.
    grunt.initConfig({
        uglify: {
            amd: {
                files: [{
                    expand: true,
                    src: amdSrc,
                    rename: uglifyRename
                }],
                options: {report: 'none'}
            }
        },
        stylelint: {
            scss: {
                options: {
                    configFile: '',
                    formatter: 'string',
                    ignoreDisables: false,
                    failOnError: true,
                    outputFile: '',
                    reportNeedlessDisables: false,
                    fix: false,
                    syntax: 'scss'
                },
                src: ['scss/*.scss']
            },
            less: {
                src: ['less/*.less']
            },
            css: {
                src: ['css/*.css']
            }
        },
        sass: {
            // Compile moodle styles.
            options: {
                implementation: sass,
                sourceMap: true
            },
            dist: {
                files: {
                    'styles.css':'scss/styles.scss'
                }
            }
        },
    });

    // Register NPM tasks.
    grunt.loadNpmTasks("grunt-sass");
    grunt.loadNpmTasks('grunt-contrib-uglify-es');
    grunt.loadNpmTasks("grunt-stylelint");

    // Register JS tasks.
    grunt.registerTask('amd', ['uglify']);
};